Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Steur <thomas.steur@gmail.com>2013-12-18 03:39:56 +0400
committerThomas Steur <thomas.steur@gmail.com>2013-12-18 03:39:56 +0400
commit899f1e2a6ef89c4f777be49047ba229a2edbee9e (patch)
tree6eae4043724ae82283f0a53782c193531d7b3c27 /core/DataTable.php
parent1c5b7696790f028f289bfa9e6779f81f1a53eab8 (diff)
rename class Filter -> BaseFilter to prevent error "two constructors are defined on PHP 5.3.2"
Diffstat (limited to 'core/DataTable.php')
-rw-r--r--core/DataTable.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/DataTable.php b/core/DataTable.php
index 7550bc4f25..aa97941971 100644
--- a/core/DataTable.php
+++ b/core/DataTable.php
@@ -14,7 +14,7 @@ namespace Piwik;
use Closure;
use Exception;
use Piwik\DataTable\DataTableInterface;
-use Piwik\DataTable\Filter;
+use Piwik\DataTable\BaseFilter;
use Piwik\DataTable\Manager;
use Piwik\DataTable\Renderer\Html;
use Piwik\DataTable\Row;
@@ -85,7 +85,7 @@ require_once PIWIK_INCLUDE_PATH . '/core/Common.php';
* applied to DataTable\Map instances. So you can visit every DataTable in a {@link DataTable\Map}
* without having to write a recursive visiting function.
*
* All predefined filters exist in the **Piwik\DataTable\Filter** namespace.
*
* _Note: For convenience, [anonymous functions](http://www.php.net/manual/en/functions.anonymous.php)
* can be used as DataTable filters._
@@ -255,7 +255,7 @@ class DataTable implements DataTableInterface
protected $tableSortedBy = false;
/**
* List of Filter queued to this table
*
* @var array
*/
@@ -399,7 +399,7 @@ class DataTable implements DataTableInterface
* to all subtables as well.
*
* @param string|Closure $className Class name, eg. `"Sort"` or "Piwik\DataTable\Filters\Sort"`. If no
* namespace is supplied, `Piwik\DataTable\Filter` is assumed. This parameter
* can also be a closure that takes a DataTable as its first parameter.
* @param array $parameters Array of extra parameters to pass to the filter.
*/
@@ -85,7 +85,7 @@ require_once PIWIK_INCLUDE_PATH . '/core/Common.php';
* without having to write a recursive visiting function.
*
- * All predefined filters exist in the **Piwik\DataTable\Filter** namespace.
+ * All predefined filters exist in the **Piwik\DataTable\BaseFilter** namespace.
*
* _Note: For convenience, [anonymous functions](http://www.php.net/manual/en/functions.anonymous.php)
@@ -255,7 +255,7 @@ class DataTable implements DataTableInterface
protected $tableSortedBy = false;
/**
- * List of Filter queued to this table
+ * List of BaseFilter queued to this table
*
* @var array
@@ -399,7 +399,7 @@ class DataTable implements DataTableInterface
*
* @param string|Closure $className Class name, eg. `"Sort"` or "Piwik\DataTable\Filters\Sort"`. If no
- * namespace is supplied, `Piwik\DataTable\Filter` is assumed. This parameter
+ * namespace is supplied, `Piwik\DataTable\BaseFilter` is assumed. This parameter
* can also be a closure that takes a DataTable as its first parameter.
* @param array $parameters Array of extra parameters to pass to the filter.